% BUILD_MODEL.M	
%
%	This program is used to build the pre- and post-earthquake
%	evaluation models for the Next Generation Benchmark Control 
%	Problem for Seismically Excited Buildings. 
%
%	No modifications should be made to this program. 
% 
%       Richard Christenson		Last Modified: 1/16/98
%

% LIST OF VARIABLES
%  A	  = cross-sectional area array (m*m)
%  Am	  = cross-sectional area of member m (m*m)
%  BC	  = boundary condition array
%  bc	  = boundary condition vector
%  bc1	  = boundary condition sub-array
%  bc2	  = boundary condition sub-array
%  Cpost  = post-earthquake damping matrix
%  Cpre   = pre-earthquake damping matrix
%  Cbarpost = post-earthquake modal damping matrix
%  Cbarpre = pre-earthquake modal damping matrix
%  Cn	  = connectivity array
%  D	  = degree-of-freedom connectivity
%  Dm	  = degree-of-freedom connectivity for member m
%  dl1a	  = floor dead load associated with floor 1
%  dl1b	  = floor dead load associated with floor 2
%  dl1c	  = floor dead load associated with floors 3-20
%  dl2	  = roof dead load associated with the roof, and penthouse
%  dlb	  = floor dead load associated with the basement floor
%  E	  = modulus of elasticity array (N/m/m)
%  Em	  = modulus of elasticity of member m (N/m/m)
%  er     = vector of reordered dof for Ritz reduction
%  et     = vector of reordered dof for Guyan reduction
%  guyn   = node numbers of vertical active dof for Guyan reduction
%  guyf   = full vertical active dof for Guyan reduction
%  guya   = actual vertical active dof for Guyan reduction
%  guyd   = actual dependent dof for Guyan reduction
%  h 	  = height vector (m)
%  hf     = height between each floor (m)
%  hol    = old height in loop (m)
%  I 	  = moment of inertia array (m*m*m*m)
%  IIn    = mapping from full dof to actual dof
%  IIgn   = mapping from dof after Ritz transformation to dof after
%	    Guyan reduction
%  IIrn   = mapping of all dof from actual dof to dof after Ritz 
%	    transformation
%  IIrn2  = mapping of active dof from actual dof to dof after Ritz 
%	    transformation
%  Im 	  = moment of inertia of member m (m*m*m*m)
%  In     = index of actual (free) degrees-of-freedom
%  Iopost = index of sorted post-earthquake natural frequencies
%  Iopre  = index of sorted pre-earthquake natural frequencies
%  i	  = index
%  ind    = index of active dof after Guyan reduction
%  indf   = index of dof after Guyan reduction
%  invM   = inverse mass matrix (M)
%  invMKpost = inverse mass matrix multiplied by the post-earthquake
%	       stiffness matrix (inv(M)*Kpost)
%  invMKpre = inverse mass matrix multiplied by the pre-earthquake
%	      stiffness matrix (inv(M)*Kpre)
%  invMCpost = inverse mass matrix multiplied by the post-earthquake
%	       damping matrix (inv(M)*Cpost)
%  invMCpre = inverse mass matrix multiplied by the pre-earthquake
%	      damping matrix (inv(M)*Cpre)
%  invVopost = inverse ordered matrix of post-earthquake mode shapes
%  invVopre  = inverse ordered matrix of pre-earthquake mode shapes
%  j	  = index
%  jj	  = index
%  K	  = global stiffness matrix
%  Kaa	  = active-active partitioned stiffness matrix
%  Kad	  = active-dependent partitioned stiffness matrix
%  Kda	  = dependent-active partitioned stiffness matrix
%  Kdd	  = dependent-dependent partitioned stiffness matrix
%  Kpre	  = pre-earthquake global stiffness matrix
%  Kpost  = post-earthquake global stiffness matrix
%  k      = index
%  km     = stiffness matrix for member m
%  Lpre   = matrix with squared natural frequencies on diagonal (eigenvalues 
%	     of invM*K) for pre-earthquake model
%  Lpost  = matrix with squared natural frequencies on diagonal (eigenvalues 
%	     of invM*K) for post-earthquake model
%  M	  = global mass matrix
%  Maa	  = active-active partitioned mass matrix
%  Mad	  = active-dependent partitioned mass matrix
%  Mda	  = dependent-active partitioned mass matrix
%  Mdd	  = dependent-dependent partitioned mass matrix
%  MM     = full mass matrix
%  MP	  = member property array
%  m      = index
%  mm     = mass matrix for member m
%  mp1-12 = member property sub-arrays
%  mr     = function finds mm and km for moment resisting member
%  Nb	  = number of bays
%  Ndof   = number of actual degrees-of-freedom
%  Ne	  = number of elements
%  Nf 	  = number of floors
%  Ng     = node numbers of dof to be kept during Guyan reduction
%  Nn	  = number of nodes
%  Nr     = node numbers of dof to be kept during Ritz reduction
%  Ns	  = number of splices
%  nmr    = function finds mm and km for non-moment resisting member
%  R	  = mass density array (kg/m/m/m or N-sec*sec/m/m/m/m)
%  Rda    = constraint matrix for Ritz transformation
%  Rdd    = other constraint matrix for Ritz transformation
%  Rm	  = mass density for member m (kg/m/m/m)
%  r	  = index
%  redstl = factor to reduce mass to account for steel already included
%  ritza  = reduced active lateral dof for Ritz transformation
%  ritza1 = actual active lateral dof for Ritz transformation
%  ritzd  = actual dependent lateral for Ritz transformation
%  ritzfa = active lateral dof for Ritz transformation
%  ritzfd = dependent lateral dof for Ritz transformation
%  ritzna = active nodes for Ritz transformation
%  ritznd = dependent nodes of later dof for Ritz transformation
%  Sf 	  = splice floor: splice is Sh above the Sf floor
%  Sh	  = splice height with respect to floor centerline level (m)
%  Tdar   =  Ritz sub-transformation matrices
%  Tdag   = Guyan sub-transformation matrices
%  Tg     = Guyan transformation matrix
%  Tr     = Ritz transformation matrix
%  Vpost  = matrix of post-earthquake mode shapes (eigenvectors of invM*Kpost)
%  Vpre   = matrix of pre-earthquake mode shapes (eigenvectors of invM*Kpre)
%  Vopost = ordered matrix of post-earthquake mode shapes
%  Vopre  = ordered matrix of pre-earthquake mode shapes
%  vseed  = random seeds to be used for measurement noise in simulation
%  w	  = width vector (m)
%  wb	  = width between each bay (m)
%  wol    = old width in loop (m)
%  wopost = post-earthquake ordered natural frequencies (rad/sec)
%  wopre  = pre-earthquake ordered natural frequencies (rad/sec)
%  x	  = nodal coordinate array (m)
%  xm	  = nodal coordinates of member m (m)
%  zeta1  = damping of first mode (2%)
%  zetapost = damping for all post-earthquake modes (max modal damping: 0.10)
%  zetapre = damping for all pre-earthquake modes (max modal damping: 0.10)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ENTER PHYSICAL DATA FOR THE LA 20-STORY BUILDING			%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% DEFINE HEIGHT AND WIDTH VECTORS
Nf             = 22;
hf	       = 13*0.3048;		% meters
h	       = hf*ones(1,Nf+1);
h(1)	       = 0;
h(2)	       = 12*0.3048;		% meters
h(3)	       = 12*0.3048;		% meters
h(4)	       = 18*0.3048;		% meters

Nb	       = 5;
wb	       = 20*0.3048;		% meters
w	       = wb*ones(1,Nb+1);
w(1)	       = 0;

% DEFINE SPLICES
Sh	       = 6*0.3048;		% meters
Sf	       = [4 7 10 13 16 19 21];
Ns	       = length(Sf);

% DETERMINE THE NUMBER OF NODES AND ELEMENTS
Nn	       = (Nb+1)*(Nf+Ns+1);
Ne	       = (Nb+1)*(Nf+Ns)+(2*Nb*Nf);

% NODAL COORDINATE ARRAY
%	x is the nodal coordinate array.  It is a 2xNn array         
%	Each column contains the horizontal and vertical distance    
%	of the corresponding node from 'node 1'.                     

r	       = 0;
x	       = zeros(2,Nn);
hol	       = 0;
jj             = 1;

for j=1:Nf+1;
   for i=1:Nb+1,
      r=r+1;
      if i==1
         wol=0;
      end
      if r==1
         x(:,r)=[0;0];
      else
         x(1,r)=wol+w(i);
         x(2,r)=hol+h(j);
         wol=x(1,r);
      end
   end
   hol=x(2,r);
   if j==Sf(jj),
      for i=1:Nb+1,
         r=r+1;
         if i==1
            wol=0;
         end
         x(1,r)=wol+w(i);
         x(2,r)=hol+Sh;
         wol=x(1,r);	
      end
      if jj<length(Sf),
         jj=jj+1;
      end
   end
end

% CONNECTIVITY
%	Cn is the element connectivity array. It is 2xNe, each column
%	contains the 2 node numbers of the corresponding element.    
%                                                                    
%       The elements are numbered columns first, left to right,      
% 	starting with the first floor and working up, then beams     
%	left to right, starting with the first floor and working up. 
jj	=1;
Cn	=zeros(2,Ne);
for i=1:Nn-(Nb+1),
   Cn(:,i)=[i;i+(Nb+1)];
end

for j=1+(Nb+1):(Nb+1):((Nf+length(Sf))*(Nb+1)+1),
   if ((j-1)/(Nb+1))==Sf(jj)+(jj-1),
      if jj<length(Sf),
         jj=jj+1;
      end
   else
      for ii=1:2,
         for k=j:j+(Nb-1),
            i=i+1;
            Cn(:,i)=[k;k+1];
         end
      end
   end
end

% BOUNDARY CONDITION
%	BC is the boundary condition array. It is 3xNn. Each column  
%	contains the boundary condition codes for the dof of the     
%	corresponding node.                                          
%                                                                    
%	A '1' indicates the dof is fixed, a '0' indicates the dof    
%	is free.                                                     

bc1	       = [1;1;0];
bc2	       = [1;0;0];

BC	       = zeros([3,Nn]);

for i=1:Nb+1;
   BC(:,i)     = bc1;
   BC(:,13)    = bc2;
   BC(:,18)    = bc2;
end

% DEFINE AREA AND MOMENT OF INERTIA 
%	A and I are 1xNXS arrays containing the cross-sectional      
%	properties.  A is the cross section area in m2 (converted from
%	in2).  I is the moment of inertia in m4 (converted from in4).

% 15x1580X W24x335 W24x229 W24x192 W24x131 W24x117 W24x84 W30x99 W30x108
%  W27x84 W24x62 W21x50 unit-area/inertia

A	= [104 68.75 56 42.75 29 98.4 67.2 56.3 38.5 34.4 24.7 ...
	   29.1 31.7 24.8 18.2 14.7 12^2/0.3048^2]*(0.3048^2/12^2);
I	= [2999 2184 1839 1451 1017 11900 7650 6260 4020 3540 2370 ...
	   3990 4470 2850 1550 984 12^4/0.3048^4]*(0.3048^4/12^4);

% DEFINE ELASTICITY AND DENSITY
%	E and R arrays containing the moduli of elasticity  
%	and the density of the material.  E is the moduli of         
%  	elasticity in N/m2 (converted from kips/in2, ksi).  R is the 
%	density in kg/m3 or N-sec2/m4 (converted from floor mass of 
%	kips-sec2/ft and steel density of lbs/ft3)

E	= [29000*(4448.22*12^2/0.3048^2) 0];
	 
redstl	= 0.954;	% reduction of mass due to steel already included
dl1a    = redstl*18.19*(4448.22/.3048)/sum(w);		% floor 1
dl1b    = redstl*19.32*(4448.22/.3048)/sum(w);		% floor 2
dl1c    = redstl*18.88*(4448.22/.3048)/sum(w);		% floor 3-20
dl2     = redstl*20.03*(4448.22/.3048)/sum(w);		% roof
dlb     = 0;						% basement

R=[491*(4.44822/0.3048^3)/(32.2*0.3048) dl1a dl1b dl1c dl2 dlb];


% MEMBER PROPERTY
%	MP is a 5xNe member property array. The rows correspond to   
%	A, I, E, R and moment resisting.  Each column contains       
%	the number of the corresponding x-section or material number 
%	for the element whose number is the column number.           

MP	=ones([5,Ne]);

% cross sectional area
mp1	       = [1 6 6 6 6 1];
mp2	       = [2 6 6 6 6 2];
mp3	       = [3 7 7 7 7 3];
mp4	       = [3 8 8 8 8 3];
mp5	       = [4 9 9 9 9 4];
mp6	       = [4 10 10 10 10 4];
mp7	       = [5 11 11 11 11 5];
mp8	       = 12*ones(1,60);
mp9	       = 13*ones(1,60);
mp10	       = 14*ones(1,20);
mp11	       = 15*ones(1,10);
mp12           = 16*ones(1,10);

MP(1,:)	=[mp1 mp1 mp1 mp1 mp2 mp2 mp2 mp2 mp3 mp3 mp3 mp3 mp3 mp3...
	 mp3 mp3 mp4 mp4 mp4 mp4 mp5 mp5 mp5 mp5 mp6 mp6 mp6 mp7...
	 mp7 mp8 mp9 mp8 mp10 mp11 mp12];

for i=180:10:390,
   MP(1,i:i+4) = 17*ones(1,5);
end

% moment of inertia (corresponds to area)
MP(2,:)        = MP(1,:);

% moduli of elasticity

for i=180:10:390,
   MP(3,i:i+4) = 2*ones(1,5);
end

% density
MP(4,180:184)  = 6*ones(1,5);
MP(4,190:194)  = 2*ones(1,5);

MP(4,200:204)  = 3*ones(1,5);

for i=210:10:380,
   MP(4,i:i+4) = 4*ones(1,5);
end
MP(4,390:394)  = 5*ones(1,5);

% moment resisting. 0=completely non-moment resisting member; 0.5=half
% moment resisting and half non-moment resisting member; 1=moment resisting
% member.

MP(5,175:179)=zeros(1,5);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET UP REQUIRED VARIABLES						%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% CONVERT NODAL CONNECTIVITY TO DEGREE-OF-FREEDOM CONNECTIVITY
D              = [3*Cn(1,:)-2;3*Cn(1,:)-1;3*Cn(1,:);
	          3*Cn(2,:)-2;3*Cn(2,:)-1;3*Cn(2,:)];

% CONVERT BOUNDARY CONDITION MATRIX TO A VECTOR
bc	       = BC(:);

% FIND MAPPING FROM FULL DOF TO ACTIVE DOF
In	       = find(bc==0);
IIn(In)	       = [1:length(In)];
Ndof           = length(In);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  ASSEMBLE THE GLOBAL MASS AND STIFFNESS MATRICES 			%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SET UP MASS AND STIFFNESS MATRICES
K	       = zeros(3*Nn);
M	       = zeros(3*Nn);

% LOOP THROUGH ELEMENTS TO FIND ELEMENT MASS AND STIFFNESS
for m = 1:Ne
   xm          = [x(:,Cn(1,m)) x(:,Cn(2,m))];
   Am          = A(MP(1,m));
   Im          = I(MP(2,m));
   Em          = E(MP(3,m));
   Rm          = R(MP(4,m));
   Dm          = D(:,m);
   if MP(5,m)==1,
      [km,mm]  = mr(xm,Am,Im,Em,Rm);
   end
   if MP(5,m)==0,
      [km,mm]  = nmr(xm,Am,Im,Em,Rm);
   end

% ASSEMBLE GLOBAL MASS AND STIFFNESS MATRICES PER DOF-CONNECTIVITY
   K(Dm,Dm)    = K(Dm,Dm)+km;
   M(Dm,Dm)    = M(Dm,Dm)+mm;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% BOUNDARY CONDITION REDUCTION						%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% CONDENSE OUT FIXED DEGREES-OF-FREEDOM FROM MASS AND STIFFNESS MATRICES
K              = K(In,In);
M	       = M(In,In);

MM=M;			% full mass matrix

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RIGID BODY REDUCTION							%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% PERFORM RITZ TRANSFORMATION TO REDUCE OUT HORIZONTAL DOF THAT ARE
% PART OF RIGID FLOOR.

% DETERMINE THE SIZE OF THE REDUCTION
ritznd	=[7 8 10 11 12 14 16 17 19 20 22 23 24 31 32 34 35 36 37 38 40 41 42 ...
	43 44 46 47 48 55 56 58 59 60 61 62 64 65 66 67 68 70 71 72 79 80 ...
	82 83 84 85 86 88 89 90 91 92 94 95 96 103 104 106 107 108 109 110 ...
	112 113 114 115 116 118 119 120 127 128 130 131 132 133 134 136 ...
	137 138 139 140 142 143 144 151 152 154 155 156 157 158 160 161 ...
	162 169 170 172 173 174 175 176 178 179 180];
ritzna	=[9 9 9 9 9 15 15 15 21 21 21 21 21 33 33 33 33 33 39 39 39 39 39 ...
	45 45 45 45 45 57 57 57 57 57 63 63 63 63 63 69 69 69 69 69 ...
	81 81 81 81 81 87 87 87 87 87 93 93 93 93 93 105 105 105 105 105 ...
	111 111 111 111 111 117 117 117 117 117 129 129 129 129 129 ...
	135 135 135 135 135 141 141 141 141 141 153 153 153 153 153 ...
	159 159 159 159 159 171 171 171 171 171 177 177 177 177 177];
ritzfd	       = (ritznd-1)*3+1;		
ritzfa	       = (ritzna-1)*3+1;
ritzd	       = IIn(ritzfd);
ritza1	       = IIn(ritzfa);

if min(ritzd)==0
   'WARNING: boundary condition selected for rigid body dof'
   return
end
ritza	       = IIn;
ritza(ritzfd)  = zeros(size(ritzfd));
ritza	       = ritza(find(ritza));
Nr             = length(ritza);

% PARTITION MASS, STIFFNESS and LOADING MATRICES
er             = [ritza ritzd];
K	       = K(er,er);
M	       = M(er,er);

% FIND MATRIX OF SYSTEM CONSTRAINTS
IIrn           = zeros(1,Ndof);
IIrn(ritza)    = 1:Nr;
IIrn2          = IIrn;
IIrn(ritzd)   = IIrn(ritza1);

Rda	       = zeros(length(ritzd),Nr);
for ii = 1:length(ritzd),
	Rda(ii,IIrn(ritza1(ii))) = 1;
end
Rdd            = -eye(length(ritzd));

%  DETERMINE TRANSFORMATION MATRIX
Tdar           = -Rdd\Rda;
Tr             = [eye(length(ritza)); Tdar];

% DETERMINE THE NEW REDUCED MASS, STIFFNESS AND LOADING MATRICES
M              = Tr'*M*Tr;
K              = Tr'*K*Tr;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GUYAN REDUCTION 							%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% REDUCE OUT ALL ROTATIONAL DOF AND MOST VERTICAL DOF

% FIND VECTOR TO PARTITION ROTATIONAL AND VERTICAL DOF FOR GUYAN REDUCTION
guyn	=[14 17 20 23 32 35 38 41 44 47 56 59 62 65 68 71 80 83 ...
	  86 89 92 95 104 107 110 113 116 119 128 131 134 137 140 143 ...
	  152 155 158 161 170 173 176 179];

ind            = zeros(3,Nn);
indf           = reshape(IIn,3,Nn);
ind(1,:)       = indf(1,:);
ind(2,guyn)    = indf(2,guyn);
guya           = IIrn2(ind(find(ind(:))));
guya           = guya(find(guya));
Ng	       = length(guya);

guyd           = 1:Nr;
guyd(guya)     = 0;
guyd           = guyd(find(guyd));
IIgn           = zeros(1,Nr);
IIgn(guya)     = 1:Ng;

et	       = [guya guyd];

% PARTITION MASS AND STIFFNESS MATRICES FOR GUYAN REDUCTION OF ROTATIONAL DOF
K	       = K(et,et);
M	       = M(et,et);

Maa	       = M(1:Ng,1:Ng);
Mdd	       = M(Ng+1:Nr,Ng+1:Nr);
Mda	       = M(Ng+1:Nr,1:Ng);
Mad	       = M(1:Ng,Ng+1:Nr);

Kaa	       = K(1:Ng,1:Ng);
Kdd	       = K(Ng+1:Nr,Ng+1:Nr);
Kda	       = K(Ng+1:Nr,1:Ng);
Kad	       = K(1:Ng,Ng+1:Nr);

% FIND THE TRANSFORMATION MATRIX
Tdag	       = -Kdd\Kda;
Tg	       = [eye(Ng);Tdag];

% DETERMINE THE NEW REDUCED MASS, STIFFNESS AND LOADING MATRICES
K	       = Kaa+Kad*Tdag;
M	       = Maa+Mad*Tdag+(Mad*Tdag)'+Tdag'*Mdd*Tdag;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DETERMINE PRE- AND POST-EARTHQUAKE STIFFNESS				%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Kpre           = (1.1^2)*K;
Kpost          = (0.9^2)*K;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FIND DAMPING MATRIX							%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% FIND NATURAL FREQUENCIES AND MODE SHAPES
invM	       = inv(M);
[Vpre,Lpre]    = eig(invM*Kpre);
[Vpost,Lpost]  = eig(invM*Kpost);

% ORDER NATURAL FREQUENCIES AND MODE SHAPES
[wopre,Iopre]  = sort(sqrt(diag(Lpre)));
[wopost,Iopost]= sort(sqrt(diag(Lpost)));
Vopre	       = Vpre(:,Iopre);
Vopost	       = Vpost(:,Iopost);
invVopre       = inv(Vopre);
invVopost      = inv(Vopost);

% MODAL DAMPING MATRIX
zeta1	       = 0.02;
zetapre	       = zeta1/wopre(1)*wopre;
zetapost       = zeta1/wopost(1)*wopost;
zetapre	       = min(zetapre,.10);
zetapost       = min(zetapost,.10);
Cbarpre	       = diag(2*zetapre.*wopre);	
Cbarpost       = diag(2*zetapost.*wopost);	

% DAMPING MATRIX
Cpre	       = M*Vopre*Cbarpre*invVopre;
Cpost	       = M*Vopost*Cbarpost*invVopost;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CALCULATE HELPFUL VALUES						%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

invMKpre       = invM*Kpre;
invMKpost      = invM*Kpost;
invMCpre       = invM*Cpre;
invMCpost      = invM*Cpost;

