function [J] = evalcrit(pre);
%
%	This function is provided as part of the sample control 
%	system for the Next Generation Benchmark Problem to 
%	calculate the pre/post-earthquake evaluation criteria for 
%	the sample control system. Defining PRE=1 indicates that
%	the pre-earthquake evaluation criteria are to be obtained,
%	and defining PRE=0 indicates that the post-earthquake 
%	evaluation criteria are to be obtained. 
%	
%	This program can be modified as necessary for your design.
%
%	Shirley Dyke		Last Modified: 2/21/98
%

if (nargin<1), pre = 1, end

% LOAD REQUIRED CONTROL SYSTEM COMPONENTS
load smpl_ctl
load smpl_dev

% DEFINE FILE NAMES FOR CONTROLLED RESPONSE DATA
if (pre==1),
  fprintf(1,'\n\nPRE-EQ PERFORMANCE CRITERIA\n\n');
  resp_files = ['pre_elc';
     		'pre_hac';
     		'pre_nor';
     		'pre_kob'];
  % UNCONTROLLED RESPONSES - as tabulated in paper
  XMAX	 = [.37959  .51705  1.0591  .56887];
  VMAX	 = [.82539  1.0450  2.9023  1.8370];
  AMAX	 = [3.1372  2.8439  9.1886  8.9544];
  DNMAX  = [6.2297  7.6232  15.644  13.353]*1e-3;
  FBMAX  = [4.3525  5.3852  11.083  9.4430]*1e6;
  XNORM  = [.80904  1.4934  2.4998  .99074];
  ANORM  = [4.7166  5.7326  10.329  9.8980];
  DNNORM = [1.2486  2.2027  3.7074  1.7807]*1e-2;
  FBNORM = [8.8863  15.565  26.247  12.913]*1e6;

elseif (pre==0)
  fprintf(1,'\n\nPOST-EQ PERFORMANCE CRITERIA\n\n');
  resp_files = ['post_elc';
     		'post_hac';
     		'post_nor';
     		'post_kob'];
  % UNCONTROLLED RESPONSES - as tabulated in paper
  XMAX	 = [.27787  .29831  .90765  .65617];
  VMAX	 = [.74801  .76065  2.6803  1.6289];
  AMAX	 = [2.8093  1.9467  7.7702  7.7383];
  DNMAX  = [4.8655  5.4667  18.484  14.223]*1e-3;
  FBMAX  = [2.0892  2.6514  8.0311  6.2433]*1e6;
  XNORM  = [.89134  1.0883  1.6862  2.3438];
  ANORM  = [3.5701  3.2855  8.8356  9.5907];
  DNNORM = [1.3712  1.5784  2.8272  3.7656]*1e-2;
  FBNORM = [6.5512  7.4823  13.465  17.986]*1e6;


end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     DEFINE REQUIRED STRUCTURAL PARAMETERS 	  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h     = [5.49 3.96*ones(1,19)]; 	   % height of each floor [m]
H     = 80.77;				   % building height [m]
mass  = [2.83 2.76*ones(1,18) 2.92]*1e5;   % seismic mass of each floor [kg]
Ms    = sum(mass);			   % building mass [kg]
W     = 54377;				   % total weight [kN]

for ii = 1:length(resp_files(:,1)),

load(resp_files(ii,:));
npts  = length(ye(:,1));
DIS   = [ye(:,1:20)];				% relative displacements
DFT   = [ye(:,1) ye(:,2:20)-ye(:,1:19)];	% interstory drifts
NDFT  = (ones(npts,1)*(1./h)).*DFT;		% normalized interstory drifts
VEL   = [ye(:,21) ye(:,22:40)-ye(:,21:39)];	% interstory velocities
ACC   = [ye(:,41:60)];				% absolute accelerations
FRCA  = [yf(:,1:nflr)];				% total force per actuator
FRCF  = [(ones(npts,1)*(ndev_flr)).*FRCA];	% total force per floor
tstep = t(2)-t(1);				% time step length

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 	CHECK CONTROL DEVICE CONSTRAINTS	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MAX ACTUATOR STROKE 
if (any(any(DFT>0.0889))), error('ACTUATOR STROKE LIMIT EXCEEDED'), end
% MAX ACTUATOR FORCE 
if (any(any(FRCA>897))), error('ACTUATOR FORCE LIMIT EXCEEDED'), end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 	CHECK CONTROL SIGNAL CONSTRAINT		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (any(any(u>10))), error('CONTROL OUTPUT VOLTAGE LIMIT EXCEEDED'), end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 	DETERMINE PERFORMANCE CRITERIA		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DETERMINE J1 VALUES (max relative displacement)
J(1,ii) = max(max(abs(DIS)))/XMAX(ii);

% DETERMINE J2 VALUES (max normalized drift)
J(2,ii) = max(max(abs(NDFT)))/DNMAX(ii);

% DETERMINE J3 VALUES (max absolute acceleration)
J(3,ii) = max(max(abs(ACC)))/AMAX(ii);

% DETERMINE J4 VALUES (max base shear)
mtimesa = (ones(npts,1)*mass).*ACC;
bshear  = sum(mtimesa');
J(4,ii) = max(abs(bshear))/FBMAX(ii);

% DETERMINE J5 VALUES (normed displacement)
J(5,ii) = max(sqrt(sum(DIS.*DIS)*tstep))/XNORM(ii);

% DETERMINE J6 VALUES (normed drift)
J(6,ii) = max(sqrt(sum(DFT.*DFT)*tstep)./h)/DNNORM(ii);

% DETERMINE J7 VALUES (normed acceleration)
J(7,ii) = max(sqrt(sum(ACC.*ACC)*tstep))/ANORM(ii);

% DETERMINE J8 VALUES (normed base shear)
J(8,ii) = max(sqrt(sum(bshear.*bshear)*tstep))/FBNORM(ii);

% DETERMINE J9 VALUES (max actuator force)
f_max 	= max(abs(FRCA));
J(9,ii) = max(f_max)/W;

% DETERMINE J10 VALUES (max stroke)
strk_max = max(abs(DFT));
J(10,ii) = max(strk_max)/XMAX(ii);

% DETERMINE J11 VALUES (max instantaneous power)
power 	 = abs(VEL.*FRCF);
J(11,ii) = max(sum(power'))/VMAX(ii)/W;

% DETERMINE J12 VALUES (total power)
J(12,ii) = sum(sqrt(sum(power.*power)*tstep))/XMAX(ii)/W;

% DETERMINE J13 VALUES (number of control devices)
J(13,ii) = ndev;

% DETERMINE J14 VALUES (number of sensors)
J(14,ii) = length(Dcd(1,:));

% DETERMINE J15 VALUES (controller order)
J(15,ii) = length(Acd(:,1));

end

% DETERMINE PERFORMANCE CRITERIA 
JJ = max(J');

% DISPLAY RESULTS
for iii=1:length(J(:,1));
   JVAL = eval(['JJ(',int2str(iii),')']);
   fprintf(1,['  J_',int2str(iii),' \t= ',num2str(JVAL,5),'\n'])
end
fprintf(1,'\n\n');

% DISPLAY FULL SET OF PERFORMANCE CRITERIA
fprintf(1,['El Centro    Hachinohe  Northridge       Kobe\n\n'])
disp(num2str(J))
