% FORM_SS.M	
%
%	This program uses the models formed in BLD_MOD and
%	the user-defined OUT and INP matrices to form the
%	state space models of the pre- and post-earthquake
%	evaluation models. 
%
%	No modifications should be made to this program. 
%
%       Richard Christenson		Last Modified: 1/16/98
%

% LIST OF VARIABLES
%  Arpost = post-earthquake reduced state space A matrix
%  Arpre  = pre-earthquake reduced state space A matrix
%  Br     = reduced state space B matrix
%  Brpost = post-earthquake reduced state space B matrix
%  Brpre  = pre-earthquake reduced state space B matrix
%  C1     = portion of the state space C matrix
%  C2post = portion of the state space post-earthquake C matrix
%  C2pre  = portion of the state space pre-earthquake C matrix
%  Crpost = post-earthquake reduced state space C matrix
%  Crpre  = pre-earthquake reduced state space C matrix
%  D1     = portion of the state space D matrix
%  D2     = portion of the state space D matrix
%  Dr     = reduced state space D matrix
%  Drpost = post-earthquake reduced state space D matrix
%  Drpre  = pre-earthquake reduced state space D matrix
%  er     = vector of reordered dof for Ritz reduction
%  et     = vector of reordered dof for Guyan reduction
%  G      = vector to multiply ground acceleration
%  Ghat   = G vector after Ritz transformation
%  Gtilda = Ghat vector after Guyan reduction
%  guya   = actual vertical active dof for Guyan reduction
%  idofx  = input dof
%  iadofx = actual input dof
%  IIn    = mapping from full dof to actual dof
%  IIrn   = mapping of all dof from actual dof to dof after Ritz 
%	    transformation
%  In     = index of actual (free) degrees-of-freedom
%  inp    = array defining input of the state space model
%  invM   = inverse global mass matrix (M)
%  MM     = full mass matrix
%  Nfi    = number of force inputs
%  Nn	  = number of nodes
%  Oc     = vector of connector output
%  odof   = degrees-of-freedom for output
%  odofr  = output dof after Ritz reduction
%  oadof  = actual reduce output dof
%  Oe     = vector of evaluation output
%  Om     = vector of measured output
%  out    = array defining output of state space model
%  P      = loading vector of controller force inputs
%  gamma  = ones vector which applies the ground accel. to horizontal dof
%  outsize= input port width of selector
%  Tdag   = Guyan sub-transformation matrices
%  Tg     = Guyan transformation matrix
%  Tr     = Ritz transformation matrix

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET UP MODEL TO ACCOMODATE USER-DEFINED CONTROL DEVICE		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% OUTPUT INDICIES
odof	       = (out(1,:)-1).*3+out(2,:);
if min(IIn(odof))==0
   'WARNING: Output Requested for a Fixed DOF...Program will Terminate'
   return
end

% FIND VECTORS TO REDUCE OUTPUT TO CONNECTOR, MEASURED AND EVALUATION
Oc	       = find(out(4,:)==1);
Om	       = find(out(5,:)==1);
Oe	       = find(out(6,:)==1);

% FORCE INPUT INDICES
Nfi	       = max(inp(1,:));
idofx	       = (inp(2,:)-1).*3+1; 
iadofx	       = IIn(idofx);
if max([iadofx IIn(idofx+1) IIn(idofx+2)])==0
   'WARNING: Input Requested for a Fixed DOF...Program will Terminate'
   return
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET UP CONTROLLER FORCE LOADING VECTOR				%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SET UP VECTOR TO INPUT CONTROL FORCES INTO STRUCTURE
P	       = zeros(Ndof,Nfi);
for i=1:length(inp(1,:))
   P(iadofx(i),inp(1,i))       = P(iadofx(i),inp(1,i))+inp(3,i);
   P(IIn(idofx(i)+1),inp(1,i)) = P(IIn(idofx(i)+1),inp(1,i))+inp(4,i);
   P(IIn(idofx(i)+2),inp(1,i)) = P(IIn(idofx(i)+2),inp(1,i))+inp(5,i);
end

% INPUT FORCE IS IN kN (NOT N)
P	       = P*(1000);

% REDUCE P VECTOR
P	       = Tr'*P(er,:);
P	       = Tg'*P(et,:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET UP GROUND ACCELERATION LOADING VECTOR				%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SET UP ONE VECTOR TO INPUT THE GROUND ACCELERATION TO HORIZONTAL DOF
gamma	       = zeros(Nn*3,1);
gamma(1:3:Nn*3)= ones(Nn,1);
gamma	       = gamma(In);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FIND STATE SPACE MODEL WITH DESIRED OUTPUT				%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

G              = MM*gamma;
Ghat           = Tr'*G(er);
Gtilda         = Tg'*Ghat(et);

% SET UP REDUCED STATE SPACE A MATRIX
Arpre	       = [zeros(Ng) eye(Ng);-invMKpre -invMCpre];
Arpost	       = [zeros(Ng) eye(Ng);-invMKpost -invMCpost];

% SET UP REDUCED STATE SPACE B MATRIX
Br	       = [zeros(Ng,1+Nfi);
	         -invM*Gtilda invM*P];
Brpre	       = Br;
Brpost	       = Br;

% SET UP REDUCED STATE SPACE C MATRIX

C1             = zeros(Nr,Ng);
C1(guya,:)     = [eye(Ng)];
C1(guyd,:)     = Tdag;

C2pre          = zeros(Nr,2*Ng);
C2post         = zeros(Nr,2*Ng);
C2pre(guya,:)  = [-invMKpre -invMCpre];
C2post(guya,:) = [-invMKpost -invMCpost];
C2pre(guyd,:)  = Tdag*[-invMKpre -invMCpre];
C2post(guyd,:) = Tdag*[-invMKpost -invMCpost];

zg             = zeros(Nr,Ng);

Crpre          = [C1 zg; zg C1; C2pre];
Crpost         = [C1 zg; zg C1; C2post];

% SET UP REDUCED STATE SPACE D MATRIX

numfrc         = length(P(1,:));
D1             = zeros(Nr,1+numfrc);
D1(guya,:)     = zeros(Ng,1+numfrc);
D1(guyd,:)     = zeros(length(guyd),1+numfrc);

D2             = zeros(Nr,1+numfrc);
D2(guya,:)     = [zeros(Ng,1) invM*P];
D2(guyd,:)     = Tdag*[zeros(Ng,1) invM*P];

Dr             = [D1;D1;D2];

% FIND OUTPUT VECTOR
ordof          = IIrn(IIn(odof));
oadof	       = ordof+out(3,:)*Nr;

% FIND REDUCED STATE SPACE C MATRIX FOR OUTPUT DESIRED
Crpre	       = Crpre(oadof,:);
Crpost	       = Crpost(oadof,:);

% FIND REDUCED STATE SPACE D MATRIX FOR OUTPUTS DESIRED
Dr	       = Dr(oadof,:);
Drpre	       = Dr;
Drpost         = Dr;

save pre_mod Arpre Brpre Crpre Drpre Om Oc Oe
save post_mod Arpost Brpost Crpost Drpost Om Oc Oe
