% SMPL_DES.m
%
%	This program designs the sample controller based on 
% 	a reduced model of the system. The sample controller
%	is a discrete-time control algorithm based on H2/LQG 
%	techniques. 
%
%	Shirley J. Dyke			Last Modified: 2/1/98
%

% LIST OF VARIABLES
%
% aa1/aa2/aa3		- Coefficients used in actuator model
% Ar/Br/Cr/Dr		- State space model of reduced structural model
% Ad/Bd/Cd/Dd		- State space model of design model (combined)
% Adev/Bdev/Cdev/Ddev	- State space model of 
%				control devices (hydraulic actuators) 
% Arpre/Brpre/Crpre/Drpre - Pre-earthquake evaluation model of structure 
% Ared/Bred/Cred/Dred	- Control design model of structure 
% Ac/Bc/Cc/Dc		- Continuous-time controller
% Acd/Bcd/Ccd/Dcd	- Discrete-time controller
% Acl/Bcl/Ccl/Dcl	- Closed loop model formed with design model
% Tcd			- Sampling time of discrete-time controller (defined)
% Dlt			- Transformation matrix - displacements to drifts
% Q			- Weighting matrix on regulated outputs
% R			- Weighting matrix on control inputs
% q1 			- weighting on responses
% r1			- weighting on control 1
% nms 			- number of floors 
% nout 			- total number of model outputs
% nst			- number of design model states
% flr 			- identify floors with control devices
% ndev_flr		- number of control devices on each floor
% nflr			- number of floors with control devices
% ndev			- total number of control devices
% snsr_acc		- accelerometer sensitivity
% snsr			- matrix gain representing sensors
% Kgain			- Full state feedback gain matrix
% Lgain			- gain matrix
% SW			- Power spectral density on ground acceleration
% SV			- Power spectral density of noise
% zvec			- Vector of regulated output indices
% fbvec			- Vector of feedback measurement indices

% LOAD REDUCED PRE-EARTHQUAKE MODEL OF STRUCTURE
load red_mod 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	DEFINE INPUTS		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nms 	= 20; 				% number of floors 
nout 	= 3*nms;			% total number of model outputs
nst	= length(Ared(:,1));		% number of design model states
flr 	= [1:20];			% identify floors with actuators
ndev_flr= [8 4 4 2*ones(1,17)]; 	% number of actuators on each floor
nflr	= length(flr);			% number of floors with actuators
ndev	= sum(ndev_flr);		% total number of actuators
q1 	= [[3]*1e-3];			% weighting on responses
r1	= 4;				% weighting on control 1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	BUILD ACTUATOR MODEL		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DEFINE ACTUATOR PARAMETERS
aa1 = 5.8128784e6;
aa2 = 5.4641931e4;
aa3 = 1.6210740e3;

% FORM CONTROL DEVICE MODEL FOR SIMULATION
Dlt	= [diag(ones(1,nms)) - diag(ones(1,nms-1),-1)];
Adev	= [-aa3*eye(nflr)];
Bdev	= [aa1*eye(nflr)  -aa1*Dlt   -aa2*Dlt];
Cdev	= eye(nflr);
Ddev	= [zeros(nflr,3*nflr)];
Of 	= [1:20];
ctrlsize = length(Cdev(:,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	 BUILD COMBINED ACTUATOR/STRUCTURE MODEL (DESIGN)	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Cconr1 = [Cred(1:nms,:)];
Dconr1 = [Dred(1:nms,2:nflr+1)];
Fconr1 = [Dred(1:nms,1)];
Cconr2 = [Cred(nms+1:2*nms,:)];
Dconr2 = [Dred(nms+1:2*nms,2:nflr+1)];
Fconr2 = [Dred(nms+1:2*nms,1)];
Cdev2  = diag([ndev_flr]);

Ad = [[Ared Bred(:,2:nflr+1)*Cdev2];
      [-aa1*(Dlt*Cconr1)-aa2*(Dlt*Cconr2)  -aa1*(Dlt*Dconr1)-aa2*(Dlt*Dconr2)+Adev]];
Bd = [[Bred(:,1);-aa1*Dlt*Fconr1-aa2*Dlt*Fconr2] [zeros(nst,nflr);aa1*eye(nflr)]];
Cd = [Cred Dred(:,2:nflr+1)*Cdev2];
Dd = [[Dred(:,1)] [zeros(nout,nflr)]];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	DESIGN CONTROLLER	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DEFINE WEIGHTING MATRICES
zvec	= [41:60];
Q 	= q1*eye(length(zvec));
R 	= diag([r1 ones(1,nflr-1)]);

% STATE FEEDBACK GAINS
Cout	= [Cd(zvec,:)];
Dout	= [Dd(zvec,2:nflr+1)];
Kgain	= lqry(Ad,Bd(:,2:nflr+1),Cout,Dout,Q,R);

% STATE ESTIMATOR
fbvec	= Om; 
numfb	= length(fbvec);
SW	= 25;
SV	= eye(numfb);
Cfb	= [Cd(fbvec,:)];
Dfb 	= [Dd(fbvec,:)];
Lgain   = lqe2(Ad,Bd(:,1),Cfb,SW,SV+Dfb(:,1)*SW*[Dfb(:,1)]',SW*[Dfb(:,1)]');

% FORM CONTINUOUS STATE-SPACE CONTROLLER
Ac	= Ad-Bd(:,2:nflr+1)*Kgain-Lgain*Cfb+Lgain*Dfb(:,2:nflr+1)*Kgain;
Bc	= Lgain;
Cc	= -Kgain;
Dc	= zeros(nflr,numfb);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	CHECK STABILITY		%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Acl,Bcl,Ccl,Dcl] = feedback(Ad,Bd,Cd,Dd,Ac,Bc,Cc,Dc,[2:nflr+1],[fbvec]);

% CHECK STABILITY OF CONTROLLER
if (max(real(eig(Ac))) > 0) 
	disp('UNSTABLE CONTROLLER !')
	break
end
% CHECK STABILITY OF CLOSED LOOP SYSTEM (w/CONTROL DESIGN MODEL)
if (max(real(eig(Acl))) > 0) 
	disp('CLOSED LOOP UNSTABLE !')
	break
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   CONVERT TO DISCRETE FORM	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tcd=0.005;
[Acd,Bcd,Ccd,Dcd] = c2dm(Ac,Bc,Cc,Dc,Tcd,'tustin');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	 INCLUDE SENSORS 	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
snsr_acc= 10/9.81; 		% Acceleration (m/sec^2) to Volts [1g = 10V]
Bcd 	= Bcd/snsr_acc;		% Adjust controller matrices accordingly
Dcd 	= Dcd/snsr_acc;
[snsr] 	= [snsr_acc*eye(5)];	% Define matrix of gains for {Sensors} block


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 	ADD GAIN ON CONTROL SIGNAL	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ugain = 30;
Bdev = Bdev/ugain;
Ddev = Ddev/ugain;
Ccd  = Ccd*ugain;
Dcd  = Dcd*ugain;

% SAVE CONTROL DEVICES, CONTROL ALGORITHM AND SENSORS
save smpl_dev Adev Bdev Cdev Ddev Of ndev_flr flr ndev nflr ctrlsize
save smpl_ctl Acd Bcd Ccd Dcd Tcd 
save smpl_snr snsr
